==> haskell-microstache-1.0.2.3-167-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microstache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microstache
version:              1.0.2.3
visibility:           public
id:                   microstache-1.0.2.3-3hBWy9MC0c3711dzcJlAlJ
key:                  microstache-1.0.2.3-3hBWy9MC0c3711dzcJlAlJ
license:              BSD-3-Clause
maintainer:           Oleg Grenrus<oleg.grenrus@iki.fi>
author:
    Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/microstache
synopsis:             Mustache templates for Haskell
description:
    Mustache templates for Haskell.

    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.

category:             Text
abi:                  f5a27d43b497530a2becfc8f40f880dc
exposed:              True
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type

import-dirs:          /usr/lib/ghc-9.4.8/site-local/microstache-1.0.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/microstache-1.0.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/microstache-1.0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microstache
hs-libraries:         HSmicrostache-1.0.2.3-3hBWy9MC0c3711dzcJlAlJ
depends:
    aeson-2.1.2.1-4ODQ1UQyjV4HqW8vjPOsEA base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2 parsec-3.1.16.1
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-7dvM9aaOf5JATet72j0BPX
    vector-0.13.2.0-JDMr93x2QgFDQPvksTJZzq

haddock-interfaces:   /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html:         /usr/share/doc/haskell-microstache/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microstache-1.0.2.3-168-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microstache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microstache
version:              1.0.2.3
visibility:           public
id:                   microstache-1.0.2.3-JfrQ67MsdnQ34lGY4ZESGZ
key:                  microstache-1.0.2.3-JfrQ67MsdnQ34lGY4ZESGZ
license:              BSD-3-Clause
maintainer:           Oleg Grenrus<oleg.grenrus@iki.fi>
author:
    Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/microstache
synopsis:             Mustache templates for Haskell
description:
    Mustache templates for Haskell.

    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.

category:             Text
abi:                  8f7f2c7a113991782342e1eb684e0421
exposed:              True
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type

import-dirs:          /usr/lib/ghc-9.4.8/site-local/microstache-1.0.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/microstache-1.0.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/microstache-1.0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microstache
hs-libraries:         HSmicrostache-1.0.2.3-JfrQ67MsdnQ34lGY4ZESGZ
depends:
    aeson-2.1.2.1-J19dEw13kUOF5hLEOQVj2r base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2 parsec-3.1.16.1
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-1i1FNKzvn6TI2R1AzcNrcz
    vector-0.13.2.0-FNdsFzivQrc5gVfjRMxS7n

haddock-interfaces:   /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html:         /usr/share/doc/haskell-microstache/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
